@@ -1,10 +1,10 @@
 #include <iostream>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablewriter.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/tablewriter>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -22,7 +22,7 @@ using namespace pqxx;
 // backend running on host foo.bar.net, logging in as user smith.
 //
 // The tablename argument determines which table the data will be written to.
-// If none is given, it defaults to "orgevents".
+// If none is given, it defaults to "pqxxorgevents".
 int main(int argc, char *argv[])
 {
   try
@@ -30,23 +30,23 @@ int main(int argc, char *argv[])
     // Set up a deferred connection to the backend
     lazyconnection C(argv[1]);
 
-    string TableName((argc > 2) ? argv[2] : "orgevents");
+    string TableName((argc > 2) ? argv[2] : "pqxxorgevents");
 
     cout << "Dropping old " << TableName << endl;
     try
     {
-      Transaction Drop(C, "drop_" + TableName);
-      Drop.Exec("DROP TABLE " + TableName);
-      Drop.Commit();
+      transaction<> Drop(C, "drop_" + TableName);
+      Drop.exec("DROP TABLE " + TableName);
+      Drop.commit();
     }
     catch (const exception &e)
     {
       cerr << "Couldn't drop table: " << e.what() << endl;
     }
 
-    Transaction T(C, "test5");
+    transaction<> T(C, "test5");
 
-    T.Exec("CREATE TABLE " + TableName + "(year INTEGER, event VARCHAR)");
+    T.exec("CREATE TABLE " + TableName + "(year INTEGER, event VARCHAR)");
 
     // NOTE: start a nested block here to ensure that our stream W is closed 
     // before we attempt to commit our transaction T.  Otherwise we might end 
@@ -92,7 +92,7 @@ int main(int argc, char *argv[])
       // (destruction of W occurs here)
     }
 
-    T.Commit();
+    T.commit();
   }
   catch (const sql_error &e)
   {
