@@ -2,11 +2,11 @@
 #include <stdexcept>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablereader.h>
-#include <pqxx/tablewriter.h>
-#include <pqxx/transaction.h>
-#include <pqxx/transactor.h>
+#include <pqxx/connection>
+#include <pqxx/tablereader>
+#include <pqxx/tablewriter>
+#include <pqxx/transaction>
+#include <pqxx/transactor>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -27,8 +27,8 @@ using namespace pqxx;
 // exist in the database that connect-string (whether the default or one
 // specified explicitly on the command line) connects to.
 //
-// The default origin table name is "orgevents"; the default destination table
-// is "events".
+// The default origin table name is "pqxxorgevents"; the default destination 
+// table is "pqxxevents".
 
 namespace
 {
@@ -42,7 +42,7 @@ public:
 
   void operator()(argument_type &T)
   {
-    T.Exec("CREATE TABLE " + m_Table + "(year INTEGER, event TEXT)");
+    T.exec("CREATE TABLE " + m_Table + "(year INTEGER, event TEXT)");
     cout << "Table " << m_Table << " created." << endl;
   }
 };
@@ -56,7 +56,7 @@ public:
 
   void operator()(argument_type &T)
   {
-    T.Exec("DELETE FROM " + m_Table);
+    T.exec("DELETE FROM " + m_Table);
   }
 
   void OnCommit()
@@ -69,19 +69,19 @@ public:
 void CheckState(tablereader &R)
 {
   if (!R != !bool(R))
-    throw logic_error("tablereader " + R.Name() + " in inconsistent state!");
+    throw logic_error("tablereader " + R.name() + " in inconsistent state!");
 }
 
 
 class CopyTable : public transactor<>
 {
-  Transaction &m_orgTrans;  // Transaction giving us access to original table
-  string m_orgTable;	    // Original table's name
-  string m_dstTable;	    // Destination table's name
+  dbtransaction &m_orgTrans; // Transaction giving us access to original table
+  string m_orgTable;	     // Original table's name
+  string m_dstTable;	     // Destination table's name
 
 public:
   // Constructor--pass parameters for operation here
-  CopyTable(Transaction &OrgTrans, string OrgTable, string DstTable) :
+  CopyTable(dbtransaction &OrgTrans, string OrgTable, string DstTable) :
     transactor<>("CopyTable"),
     m_orgTrans(OrgTrans),
     m_orgTable(OrgTable),
@@ -126,25 +126,25 @@ int main(int argc, char *argv[])
     lazyconnection orgC(ConnStr), dstC(ConnStr);
 
     // Select our original and destination table names
-    const string orgTable = ((argc > 2) ? argv[2] : "orgevents");
-    const string dstTable = ((argc > 3) ? argv[3] : "events");
+    const string orgTable = ((argc > 2) ? argv[2] : "pqxxorgevents");
+    const string dstTable = ((argc > 3) ? argv[3] : "pqxxevents");
 
     // Set up a transaction to access the original table from
-    Transaction orgTrans(orgC, "test25org");
+    transaction<> orgTrans(orgC, "test25org");
  
     // Attempt to create table.  Ignore errors, as they're probably one of:
     // (1) Table already exists--fine with us
     // (2) Something else is wrong--we'll just fail later on anyway
     try
     {
-      dstC.Perform(CreateTable(dstTable));
+      dstC.perform(CreateTable(dstTable));
     } 
     catch (const sql_error &)
     {
     }
 
-    dstC.Perform(ClearTable(dstTable));
-    dstC.Perform(CopyTable(orgTrans, orgTable, dstTable));
+    dstC.perform(ClearTable(dstTable));
+    dstC.perform(CopyTable(orgTrans, orgTable, dstTable));
   }
   catch (const sql_error &e)
   {
