@@ -2,9 +2,9 @@
 #include <stdexcept>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablereader.h>
-#include <pqxx/transaction.h>
+#include <pqxx/connection>
+#include <pqxx/tablereader>
+#include <pqxx/transaction>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -20,7 +20,7 @@ using namespace pqxx;
 // called template1, or "host=foo.bar.net user=smith" to connect to a backend 
 // running on host foo.bar.net, logging in as user smith.
 //
-// The default table name is "events" as used by other test programs.
+// The default table name is "pqxxevents" as used by other test programs.
 // PostgreSQL currently implements pg_tables as a view, which cannot be read by
 // using the COPY command.  Otherwise, pg_tables would have made a better 
 // default value here.
@@ -29,13 +29,13 @@ int main(int argc, char *argv[])
   try
   {
     // Set up a connection to the backend
-    LazyConnection C(argv[1]);
+    lazyconnection C(argv[1]);
 
-    string Table = "events";
+    string Table = "pqxxevents";
     if (argc > 2) Table = argv[2];
 
     // Begin a transaction acting on our current connection
-    Transaction T(C, "test27");
+    transaction<> T(C, "test27");
 
     vector<string> R, First;
 
@@ -63,13 +63,13 @@ int main(int argc, char *argv[])
       tablereader Verify(T, Table);
       string Line;
 
-      if (!Verify.GetRawLine(Line))
+      if (!Verify.get_raw_line(Line))
 	throw logic_error("tablereader got rows the first time around, "
 	                  "but none the second time!");
 
       cout << "First tuple was: " << endl << Line << endl;
 
-      Verify.Tokenize(Line, R);
+      Verify.tokenize(Line, R);
       if (R != First)
         throw logic_error("Got different results re-parsing first tuple!");
     }
